@@ -8,23 +8,6 @@ from util import *
 
 _link_line_re = re.compile(r"&gt;&gt; *([0-9]+) *")
 
-def get_board_or_die(s, board_name):
-    board = s.query(Board).filter(Board.short_name == board_name).first()
-    if not board:
-        raise HTTPError(404, "No such board.")
-    return board
-
-
-def get_thread_in_board_or_die(s, board, thread_id):
-    thread = (s.query(Thread)
-              .filter(Thread.id == thread_id)
-              .filter(Thread.board == board)
-              .first())
-    if not thread:
-        raise HTTPError(404, "No such thread.")
-    return thread
-
-
 def sanitize_content(s, content):
     lines = []
     for line in content.split('\n'):
@@ -50,43 +33,35 @@ def index():
     return dict(boards=boards)
 
 
-@get('/setup')
-def create_a_board():
-    b = Board(short_name='test')
-    s.add(b)
-    t = Thread(board=b)
-    s.add(t)
-    s.add(Post(
-            thread=t, content="This is a post", poster_ip='1.2.3.4',
-            poster_name="poster_name", subject="subject"))
-    u = User(username='admin')
-    u.password = 'adminadmin1'
-    s.add(u)
-    return dict()
-
-
 from login import *
 
 from moderation import *
 
+from atom import *
+
+
+def _get_image(fetch_func, image):
+    try:
+        i_data = fetch_func(image)
+        response.content_type = 'image/' + image.split('.')[-1]
+        return i_data
+    except ImageNotFoundError:
+        raise HTTPError(404, "Not found")
+
 
 @get('/t_/:image', name='thumb')
 @cache_forever
 def get_thumbnail(image):
-    thumb_data = fetch_thumb(image)
-    response.content_type = 'image/' + image.split('.')[-1]
-    return thumb_data
+    return _get_image(fetch_thumb, image)
 
 
 @get('/i_/:image', name='image')
 @cache_forever
 def get_image(image):
-    image_data = fetch_image(image)
-    response.content_type = 'image/' + image.split('.')[-1]
-    return image_data
+    return _get_image(fetch_image, image)
 
 
-@get('/:board_name/', name='board')
+@get('/:board_name#[^_.][^./]*#', name='board')
 @get('/:board_name/page/:page#[0-9]+#', name='board_page')
 @view('board.tpl')
 def board(board_name, page=None):
@@ -94,7 +69,7 @@ def board(board_name, page=None):
     page_offset = int(page or 0) * c.threads_per_page
     threads = (s.query(Thread)
                .filter(Thread.board == board)
-               .order_by(desc(Thread.last_post_time))
+               .order_by(desc(Thread.pinned), desc(Thread.last_post_time))
                .offset(page_offset).limit(c.threads_per_page))
     threads = [thread for thread in threads if thread.posts]
     return dict(board=board, threads=threads)
@@ -106,12 +81,16 @@ def remember_poster_prefs(poster_name, use_tripcode):
         vp = Visitor(cookie_uuid=str(uuid4()))
         s.add(vp)
         set_cookie(VisitorPrefsCookie(vp.cookie_uuid))
+        c.visitor_prefs = vp
     vp.poster_name = poster_name
     vp.use_tripcode = use_tripcode
+    s.flush()
 
 
 def handle_post(board_name, thread_id=None):
     board = get_board_or_die(s, board_name)
+    assert_not_banned(board)
+    assert_not_locked(board)
     if thread_id:
         thread = get_thread_in_board_or_die(s, board, thread_id)
     else:
@@ -146,8 +125,7 @@ def post_thread(board_name):
     return handle_post(board_name)
 
 
-@get('/:board_name/:thread_id#[0-9]+#/', name='thread')
-@get('/:board_name/:thread_id#[0-9]+#')
+@get('/:board_name/:thread_id#[0-9]+#', name='thread')
 @view('thread.tpl')
 def thread(board_name, thread_id):
     board = get_board_or_die(s, board_name)
@@ -161,10 +139,7 @@ def post_reply(board_name, thread_id):
     return handle_post(board_name, thread_id)
 
 
-get(r'/:board_name#[^.]+#')(board)
-
-
-@get(r'/:file#.+\..+#', name='static')
+@get(r'/:file', name='static')
 @cache_forever
 def static(file):
     if file.split('.')[-1] in ('py', 'pyo', 'pyc'):
@@ -172,9 +147,12 @@ def static(file):
     mime_type, encoding = guess_type(file)
     if mime_type:
         response.content_type = mime_type
-    return open(STATIC_PATH + os.sep + file, 'rb').read()
+    f = STATIC_PATH + os.sep + file
+    if not os.path.exists(f):
+        raise HTTPError(404, "Not found")
+    return open(STATIC_PATH + os.sep + file, 'rb')
 
 
-@error(404)
-def error404(msg):
-    return "Page not found."
+#@error(404)
+#def error404(msg):
+#    return "Page not found."
