@@ -1,6 +1,6 @@
 
 from bottle import response
-from .db import VisitorPrefs, User
+from .db import Visitor, User
 
 
 class AuthCookie(object):
@@ -26,12 +26,13 @@ class VisitorPrefsCookie(object):
 
     @property
     def visitor_prefs(self):
-        return (s.query(VisitorPrefs)
-                .filter(VisitorPrefs.cookie_uuid == self.cookie_uuid).first())
+        return (s.query(Visitor)
+                .filter(Visitor.cookie_uuid == self.cookie_uuid).first())
 
 
 def set_cookie(cookie):
-    response.set_cookie(cookie.cookie_key, cookie, cookie.cookie_secret)
+    response.set_cookie(cookie.cookie_key, cookie, cookie.cookie_secret,
+                        path='/')
 
 
 def wipe_cookie(cookie):
