@@ -3,11 +3,12 @@ from __future__ import with_statement
 
 import math
 from sha import sha
+from datetime import datetime
 
 from sqlalchemy import (
     create_engine,
     Table, Column, Integer, String, MetaData, ForeignKey, DateTime,
-    func, Boolean,
+    func, or_
     )
 from sqlalchemy.ext.declarative import declarative_base
 from sqlalchemy.orm import sessionmaker, relationship, backref
@@ -57,23 +58,38 @@ def DbSessionMiddleware(wrapped_app):
     return _DbSessionMiddleware
 
 
+def get_all_visible_boards():
+    return s.query(Board).filter(Board.hidden == 0).all()
+
+
 class Board(Base):
     __tablename__ = 'boards'
 
     id = Column(Integer, primary_key=True)
     short_name = Column(String, nullable=False, unique=True)
+    locked = Column(Integer(1), nullable=False, default=0)
+    hidden = Column(Integer(1), nullable=False, default=0)
+    long_name = Column(String, nullable=False, unique=True)
+
 
     @property
     def num_pages(self):
         return int(math.ceil(float(len(self.threads)) / c.threads_per_page))
 
 
+    @property
+    def pretty_title(self):
+        return "/%s/ - %s" % (self.short_name, self.long_name)
+
+
 class Thread(Base):
     __tablename__ = 'threads'
 
     id = Column(Integer, primary_key=True)
     board_id = Column(Integer, ForeignKey('boards.id'), nullable=False)
     last_post_time = Column(DateTime)
+    pinned = Column(Integer(1), nullable=False, default=0)
+    locked = Column(Integer(1), nullable=False, default=0)
 
     board = relationship(Board,
                          backref=backref(
@@ -139,7 +155,7 @@ class User(Base):
         raise Exception("Write only")
     def _set_password(self, v):
         self.password_hash = self._calc_password(v)
-        return locals()
+
     password = property(_get_password, _set_password)
 
 
@@ -154,7 +170,28 @@ class Visitor(Base):
     cookie_uuid = Column(String, unique=True, nullable=False)
     poster_name = Column(String, nullable=False, default='')
     tripcode = Column(String, nullable=False, default=random_str)
-    use_tripcode = Column(Boolean, nullable=False, default=False)
+    use_tripcode = Column(Integer(1), nullable=False, default=0)
+
+
+class IpBan(Base):
+    __tablename__ = 'ip_ban'
+
+    id = Column(Integer, primary_key=True)
+    ip_address = Column(String, nullable=False)
+    ban_start = Column(DateTime, nullable=False, default=func.now())
+    ban_expire = Column(DateTime, nullable=True, default=None)
+
+    @property
+    def is_active(self):
+        return self.ban_expire == None or self.ban_expire > datetime.now()
+
+    @classmethod
+    def ip_is_banned(cls, ip_addr):
+        return (s.query(IpBan).filter(IpBan.ip_address == ip_addr)
+                .filter(or_(
+                    IpBan.ban_expire > func.now(),
+                    IpBan.ban_expire == None))
+                .count())
 
 
 def configure_db(db_uri, echo=False):
