@@ -1,13 +1,13 @@
 
 from util import *
 
-@get('/login', name='login')
+@get('/mod/login', name='login')
 @view('login.tpl')
 def login():
     return dict()
 
 
-@post('/log_me_in_please', name='login_submit')
+@post('/mod/log_me_in_please', name='login_submit')
 @view('message.tpl')
 def login_submit():
     user = (s.query(User).filter(User.username == request.POST.get('username'))
@@ -16,10 +16,10 @@ def login_submit():
         return dict(message="Nope, that's not it", redirect=url('login'))
     else:
         set_cookie(AuthCookie(user.id))
-        return dict(message="You are now logged in", redirect=url('index'))
+        return dict(message="You are now logged in", redirect=url('mod_home'))
 
 
-@post('/log_me_out_please', name='logout_submit')
+@post('/mod/log_me_out_please', name='logout_submit')
 @view('message.tpl')
 def logout_submit():
     wipe_cookie(AuthCookie)
